ErrorCode class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- CONNECTION_REFUSED → const ErrorCode
- DNS_FAILED → const ErrorCode
- FILE_ERROR → const ErrorCode
- HOST_UNREACHABLE → const ErrorCode
- INTERNAL_ERROR → const ErrorCode
- INVALID_CONNECTION → const ErrorCode
- INVALID_PROTOCOL → const ErrorCode
- INVALID_URL → const ErrorCode
- MAX_CONNECTIONS → const ErrorCode
- NETWORK_UNREACHABLE → const ErrorCode
- NONE → const ErrorCode
- NOT_CONNECTED → const ErrorCode
- RECEIVE_FAILED → const ErrorCode
- SEND_FAILED → const ErrorCode
- TIMEOUT → const ErrorCode
- TLS_FAILED → const ErrorCode
-
values
→ const List<
ErrorCode>